Module types

Module types 

The public type surface of dig-did (SPEC 2).

Two kinds of types live here: the DID/coin types re-exported verbatim from chia-wallet-sdk (the byte-source-of-truth, INV-4 — this crate never re-defines a puzzle-carrying type), and the small dig-did-owned types that describe an unsigned operation result (DidSpend) and who is authorized to spend a DID (Owner).

Structs

Coin
CoinSpend
DidInfo
Information needed to construct the outer puzzle of a DID. It does not include the inner puzzle, which must be stored separately.
DidSpend
The result of building a DID operation: the unsigned coin spends plus the recreated child DID.
LineageProof

Enums

Owner
Who is authorized to spend a DID — i.e. the p2 (“inner”) puzzle that guards it.
Proof

Type Aliases

Bytes32
Did
Contains all information needed to spend the outer puzzles of DID coins. The DidInfo is used to construct the puzzle, but the Proof is needed for the solution.